@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -14,7 +14,7 @@ FilterImporterTest::FilterImporterTest(MailImporter::FilterInfo *info)
 
 bool FilterImporterTest::importMessage(const QString &folderName, const QString &msgPath, bool duplicateCheck, const MailImporter::MessageStatus &status)
 {
-    Q_UNUSED(status);
+    Q_UNUSED(status)
     qDebug() << "FilterImporterTest::importMessage folderName " << folderName << " msgPath " << msgPath << " duplicateCheck " << duplicateCheck;
     return false;
 }
@@ -39,10 +39,10 @@ QString FilterImporterTest::topLevelFolder() const
 
 bool FilterImporterTest::importMessage(const KArchiveFile *file, const QString &folderPath, int &nbTotal, int &fileDone)
 {
-    Q_UNUSED(file);
-    Q_UNUSED(folderPath);
-    Q_UNUSED(nbTotal);
-    Q_UNUSED(fileDone);
+    Q_UNUSED(file)
+    Q_UNUSED(folderPath)
+    Q_UNUSED(nbTotal)
+    Q_UNUSED(fileDone)
     return false;
 }
 
